lck.crypto
==========

.. automodule:: lck.crypto

Factory functions
-----------------

These are convenience routines that create :class:`Cipher` instances with the
correct algorithm implementation plugged in.

.. autofunction:: aes
.. autofunction:: blowfish
.. autofunction:: cast
.. autofunction:: des
.. autofunction:: des3

Classes
-------

.. autoclass:: lck.crypto.cipher.Cipher
   :members:
   :member-order: bysource
   :content: both
